@@ -23,7 +23,7 @@
 
 This file uploads a file on a WebScripts Server."""
 
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -95,6 +95,13 @@ def parse_args() -> Namespace:
         action="store_true",
         default=False,
     )
+    parser.add_argument(
+        "--no-compression",
+        "-c",
+        help="Do not compress the file.",
+        action="store_true",
+        default=False,
+    )
     parser.add_argument(
         "--is-b64",
         "-i",
